# pyvizbee
[![pytest](https://github.com/ffreemt/vizbee/actions/workflows/routine-tests.yml/badge.svg)](https://github.com/ffreemt/vizbee/actions)[![python](https://img.shields.io/static/v1?label=python+&message=3.8%2B&color=blue)](https://www.python.org/downloads/)[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)[![PyPI version](https://badge.fury.io/py/pyvizbee.svg)](https://badge.fury.io/py/pyvizbee)

a dualtext aligner based on holoviz panel

## Use it
### `git clone`
```bash
git clone https://github.com/ffreemt/vizbee
cd vizbee
poetry install  # or pip install requirements.txt
poetry shell
panel serve vizbee/vizbee.py
```

### `pypi`
```shell
**NOTREADY** pip install pyvizbee
python -m pyvizbee

```
